<?php
/**
 * Custom template tags for this theme
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package ocius
 */

if (!function_exists('ocius_posted_on')) :
    /**
     * Prints HTML with meta information for the current post-date/time.
     */
    function ocius_posted_on()
    {
        $time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';
        if (get_the_time('U') !== get_the_modified_time('U')) {
            $time_string = '<time class="entry-date published" datetime="%1$s" '.ocius_get_microdata('date-published').'>%2$s</time><time class="updated" datetime="%3$s" '.ocius_get_microdata('date-modified').'>%4$s</time>';
        }

        $time_string = sprintf($time_string,
            esc_attr(get_the_date(DATE_W3C)),
            esc_html(get_the_date()),
            esc_attr(get_the_modified_date(DATE_W3C)),
            esc_html(get_the_modified_date())
        );

        $posted_on = sprintf(
            '%s',
            '<i class="fa fa-calendar"></i><a href="' . esc_url(get_permalink()) . '" rel="bookmark">' . $time_string . '</a>'
        );


        echo '<span class="posted-on">' . $posted_on . '</span>'; // WPCS: XSS OK.

    }
endif;

if (!function_exists('ocius_posted_by')) :
    /**
     * Prints HTML with meta information for the current author.
     */
    function ocius_posted_by()
    {
        $byline = sprintf(
            '%s',
            '<span class="author vcard" '.ocius_get_microdata('post-author').'><i class="fa fa-user"></i><a class="url fn n" href="' . esc_url(get_author_posts_url(get_the_author_meta('ID'))) . '" rel="author"><span class="author-name" '.ocius_get_microdata('post-author-name').'>' . esc_html(get_the_author()) . '</span></a></span>'
        );

        echo '<span class="byline"> ' . $byline . '</span>'; // WPCS: XSS OK.

    }
endif;

if (!function_exists('ocius_entry_category')) :
    /**
     * Prints HTML with meta information for the categories
     */
    function ocius_entry_category()
    {
        // Hide category for pages.
        if ('post' === get_post_type()) {
            /* translators: used between list items, there is a space after the comma */
            $categories_list = get_the_category_list(esc_html__(', ', 'ocius'));
            if ($categories_list) {
                /* translators: 1: list of categories. */
                printf('<span class="cat-links"><i class="fa fa-folder-open"></i> ' . esc_html__('%1$s', 'ocius') . '</span>', $categories_list); // WPCS: XSS OK.
            }
        }
    }

endif;

if (!function_exists('ocius_entry_footer')) :
    /**
     * Prints HTML with meta information for the tags and comments.
     */
    function ocius_entry_footer()
    {
        global $ocius_theme_options;
        if(is_singular()){
            $show_tags = $ocius_theme_options['ocius-enable-single-tags'];

        }else{
            $show_tags = $ocius_theme_options['ocius-enable-blog-tags'];
        }
        // Hide  tag text for pages.
        if ('post' === get_post_type() && $show_tags == 1 ) {

            /* translators: used between list items, there is a space after the comma */
            $tags_list = get_the_tag_list('', esc_html_x(', ', 'list item separator', 'ocius'));
            if ($tags_list) {
                /* translators: 1: list of tags. */
                printf('<span class="tags-links"><i class="fa fa-tags"></i>' . esc_html__('%1$s', 'ocius') . '</span>', $tags_list); // WPCS: XSS OK.
            }
        }

        if (!is_single() && !post_password_required() && (comments_open() || get_comments_number())) {
            echo '<span class="comments-link"><i class="fa fa-comment-o"></i>';
            comments_popup_link(
                sprintf(
                    wp_kses(
                    /* translators: %s: post title */
                        __('Leave a Comment<span class="screen-reader-text"> on %s</span>', 'ocius'),
                        array(
                            'span' => array(
                                'class' => array(),
                            ),
                        )
                    ),
                    get_the_title()
                )
            );
            echo '</span>';
        }

        edit_post_link(
            sprintf(
                wp_kses(
                /* translators: %s: Name of current post. Only visible to screen readers */
                    __('Edit <span class="screen-reader-text">%s</span>', 'ocius'),
                    array(
                        'span' => array(
                            'class' => array(),
                        ),
                    )
                ),
                get_the_title()
            ),
            '<span class="edit-link"><i class="fa fa-pencil"></i>',
            '</span>'
        );
    }
endif;

if (!function_exists('ocius_post_thumbnail')) :
    /**
     * Displays an optional post thumbnail.
     *
     * Wraps the post thumbnail in an anchor element on index views, or a div
     * element when on single views.
     */
    function ocius_post_thumbnail()
    {
        if (post_password_required() || is_attachment() || !has_post_thumbnail()) {
            return;
        }

        if (is_singular()) :
            ?>

            <div class="post-thumbnail">
            <?php
                the_post_thumbnail('ocius-large-thumb', array(
                    'alt' => the_title_attribute(array(
                        'echo' => false,
                    )),
                    'itemprop' => 'image'
                ));

                ?>
            </div><!-- .post-thumbnail -->

        <?php else : ?>

            <a class="post-thumbnail" href="<?php the_permalink(); ?>" aria-hidden="true" tabindex="-1">
                <?php
                the_post_thumbnail('ocius-large-thumb', array(
                    'alt' => the_title_attribute(array(
                        'echo' => false,
                    )),
                    'itemprop' => 'image'
                ));
                ?>
            </a>

        <?php
        endif; // End is_singular().
    }
endif;
